==> lwc-dev-server-dependencies-1.0.77.tgz: package/vendors/dependencies-228/lightning-pkg/src/lightning/pill/__docs__/pill.md <==
---
examples:
 - name: basic
   label: Basic Pills
   description: Pills can include links and use separate handlers for clicks on the label text and the remove button (X).
 - name: avatarPill
   label: Pill With an Avatar
   description: A pill includes an avatar by nesting a lightning-avatar component.
 - name: iconPill
   label: Pill With an Icon
   description: A pill includes an icon by nesting a lightning-icon component.
 - name: errorPill
   label: Pill With an Error
   description: A pill indicates an error condition by specifying the has-error attribute.
---
A `lightning-pill` component represents an item, such as an account name or
case number. By default, pills are rendered with a remove button. They are useful for displaying read-only text that can be added and removed on demand, for example, a list of
email addresses or a list of keywords.

This component inherits styling from
[pills](https://www.lightningdesignsystem.com/components/pills) in the
Lightning Design System.

Use the `class` attribute to apply additional styling.

This example creates a basic pill.

```html
<template>
    <lightning-pill
        label="Pill Label"
        href="/path/to/some/where"
        onremove={handleRemove}>
    </lightning-pill>
</template>
```

#### Inserting an Icon or Avatar

A pill can contain an icon or avatar to represent the type of object. Nest a `lightning-icon` or `lightning-avatar` component inside the `lightning-pill` component.

Insert an icon on the pill using `lightning-icon`. For more information, see [lightning-icon](bundle/lightning-icon/documentation).

```html
<template>
    <lightning-pill
        name="account"
        label="Pill Label"
        href="/path/to/some/where">
                <lightning-icon
                    icon-name="standard:account"
                    alternative-text="Account">
                </lightning-icon>
    </lightning-pill>
</template>
```

Insert an avatar on the pill using `lightning-avatar`. For more information, see [lightning-avatar](bundle/lightning-avatar/documentation).

```html
<template>
    <lightning-pill
        name="user"
        label="User Name">
        <lightning-avatar src="https://www.lightningdesignsystem.com/assets/images/avatar2.jpg" 
            fallback-icon-name="standard:user"
            alternative-text="User avatar"
            variant="circle"></lightning-avatar>
    </lightning-pill>
</template>
```

#### Interacting with Pills

A pill has three clickable elements.
* The optional icon or avatar
* The text label
* The remove button

All three elements trigger the `onclick` handler when clicked. If you provide an `href` value, clicking the text label triggers the `onclick` handler and then takes you to the provided path.

Clicking the remove button on the pill fires the `remove` event and then the `click` event. Use the optional `onremove` and `onclick` handlers to remove the pill and perform an action. You must hide or remove the pill on your own using the `onremove` handler, as shown in the example below. If you don't specify a pill removal behavior, clicking the remove button doesn't have a visible effect.

When an `href` value is present, clicking the text label navigates to a link, but clicking the icon or avatar does not. To prevent your browser from navigating to a link when it's clicked, call `event.preventDefault()` in the `onclick` handler. 

To disable anchor links, set `variant="plain"`, which removes an anchor link from a pill.

This example hides a pill when the remove button is clicked. 

```html
<template if:true={showPill}>
    <lightning-pill
        label="account"
        href="/path/to/some/where"
        onremove={handleRemoveOnly}
        onclick={handleClick}>
    </lightning-pill>
</template>
```

To prevent navigating to the link when the remove button is clicked, call `event.preventDefault()` in the `onremove` handler.  The `click` event is still fired when you click the text label. However, calling `event.preventDefault()` in the `onremove` handler prevents the `click` event from firing when you click the remove button. 

```javascript
import { LightningElement } from 'lwc';
export default class PillRemoveExample extends LightningElement {

    showPill = true;

    handleRemoveOnly(event) {
        event.preventDefault();
        this.showPill = !this.showPill;
    }

    handleClick(event) {
        // this won't run when you click the remove button
        alert('The pill was clicked!');
    }
}
```

#### Displaying an Error

Display a pill in an error state when the containing text doesn't match a
pre-defined collection of items, such as when an email address is invalid or a
case number doesn't exist.

Use the `has-error` attribute to denote an error on a pill. This attribute inserts an error icon next to the label and changes the border to red for the `link` variant (default). Providing your own image in this context has no effect on the pill; the error icon is still displayed.

```html
<template>
        <lightning-pill label="Pill with error" 
            href="/path/to/some/where"
            has-error>
        </lightning-pill>
</template>
```

#### Usage Considerations

Icons are not available in Lightning Out, but they are available in Lightning Components for Visualforce and other experiences.

To create more than one pill, use the `lightning-pill-container` component, which gives you access to the pill array via the `itemremove` event.

Specifying a target to change where the link should open is not supported. By default, the link opens on the same tab or window. To create a URL that navigates to another page in Salesforce, use
[`lightning-navigation`](bundle/lightning-navigation/documentation).

This component has usage differences from its Aura counterpart. See [Base Components: Aura Vs Lightning Web Components](docs/component-library/documentation/lwc/lwc.migrate_map_aura_lwc_components) in the Lightning Web Components Developer Guide.

#### Accessibility

When using `lightning-avatar`, use the `alternative-text` attribute to describe the avatar, such as a user's initials or name. This description provides the value for the `alt` attribute in the `img` HTML tag.

When using `lightning-icon`, use the `alternative-text` attribute to describe the icon. For example, specify "Account" instead of "Pill icon". This description is used as assistive text on the pill.

Press the Tab key to focus on a pill. To remove a pill, press the Delete or Backspace key on the pill when it receives focus. Alternatively, press the Enter key when you tab to the remove button. You can define your own behavior to remove the pill from view, such as using the `onremove` handler  shown in __Interacting with Pills__. Press the Enter key to navigate to a link on a pill.

#### Custom Events

**`remove`**

The event fired when a pill is removed.

The `remove` event returns the following parameter.

Parameter|Type|Description
-----|-----|----------
name|string|The name of the pill that's removed.

The event properties are as follows.

Property|Value|Description
-----|-----|----------
bubbles|false|This event does not bubble.
cancelable|true|This event can be canceled. You can call `preventDefault()` on this event to prevent the `click` event from being fired.
composed|false|This event does not propagate outside the template in which it was dispatched.

==> lwc-dev-server-dependencies-1.0.87.tgz: package/vendors/dependencies-228/lightning-pkg/src/lightning/pill/__docs__/pill.md <==
---
examples:
 - name: basic
   label: Basic Pills
   description: Pills can include links and use separate handlers for clicks on the label text and the remove button (X).
 - name: avatarPill
   label: Pill With an Avatar
   description: A pill includes an avatar by nesting a lightning-avatar component.
 - name: iconPill
   label: Pill With an Icon
   description: A pill includes an icon by nesting a lightning-icon component.
 - name: errorPill
   label: Pill With an Error
   description: A pill indicates an error condition by specifying the has-error attribute.
---
A `lightning-pill` component represents an item, such as an account name or
case number. By default, pills are rendered with a remove button. They are useful for displaying read-only text that can be added and removed on demand, for example, a list of email addresses or a list of keywords.

This example creates a basic pill.

```html
<template>
    <lightning-pill
        label="Pill Label"
        href="/path/to/some/where"
        onremove={handleRemove}>
    </lightning-pill>
</template>
```

#### Inserting an Icon or Avatar

A pill can contain an icon or avatar to represent the type of object. Nest a `lightning-icon` or `lightning-avatar` component inside the `lightning-pill` component.

Insert an icon on the pill using `lightning-icon`. For more information, see [lightning-icon](bundle/lightning-icon/documentation).

```html
<template>
    <lightning-pill
        name="account"
        label="Pill Label"
        href="/path/to/some/where">
                <lightning-icon
                    icon-name="standard:account"
                    alternative-text="Account">
                </lightning-icon>
    </lightning-pill>
</template>
```

Insert an avatar on the pill using `lightning-avatar`. For more information, see [lightning-avatar](bundle/lightning-avatar/documentation).

```html
<template>
    <lightning-pill
        name="user"
        label="User Name">
        <lightning-avatar src="https://www.lightningdesignsystem.com/assets/images/avatar2.jpg" 
            fallback-icon-name="standard:user"
            alternative-text="User avatar"
            variant="circle"></lightning-avatar>
    </lightning-pill>
</template>
```

#### Interacting with Pills

A pill has three clickable elements.
* The optional icon or avatar
* The text label
* The remove button

All three elements trigger the `onclick` handler when clicked. If you provide an `href` value, clicking the text label triggers the `onclick` handler and then takes you to the provided path.

Clicking the remove button on the pill fires the `remove` event and then the `click` event. Use the optional `onremove` and `onclick` handlers to remove the pill and perform an action. You must hide or remove the pill on your own using the `onremove` handler, as shown in the example below. If you don't specify a pill removal behavior, clicking the remove button doesn't have a visible effect.

When an `href` value is present, clicking the text label navigates to a link, but clicking the icon or avatar does not. To prevent your browser from navigating to a link when it's clicked, call `event.preventDefault()` in the `onclick` handler. 

To disable anchor links, set `variant="plain"`, which removes an anchor link from a pill.

This example hides a pill when the remove button is clicked. 

```html
<template if:true={showPill}>
    <lightning-pill
        label="account"
        href="/path/to/some/where"
        onremove={handleRemoveOnly}
        onclick={handleClick}>
    </lightning-pill>
</template>
```

To prevent navigating to the link when the remove button is clicked, call `event.preventDefault()` in the `onremove` handler.  The `click` event is still fired when you click the text label. However, calling `event.preventDefault()` in the `onremove` handler prevents the `click` event from firing when you click the remove button. 

```javascript
import { LightningElement } from 'lwc';
export default class PillRemoveExample extends LightningElement {

    showPill = true;

    handleRemoveOnly(event) {
        event.preventDefault();
        this.showPill = !this.showPill;
    }

    handleClick(event) {
        // this won't run when you click the remove button
        alert('The pill was clicked!');
    }
}
```

#### Displaying an Error

Display a pill in an error state when the containing text doesn't match a
pre-defined collection of items, such as when an email address is invalid or a
case number doesn't exist.

Use the `has-error` attribute to denote an error on a pill. This attribute inserts an error icon next to the label and changes the border to red for the `link` variant (default). Providing your own image in this context has no effect on the pill; the error icon is still displayed.

```html
<template>
        <lightning-pill label="Pill with error" 
            href="/path/to/some/where"
            has-error>
        </lightning-pill>
</template>
```

#### Component Styling

`lightning-pill` implements the 
[pills](https://www.lightningdesignsystem.com/components/pills) blueprint in the
Salesforce Lightning Design System (SLDS).

To apply additional styling, use the SLDS [utility classes](https://www.lightningdesignsystem.com/utilities/alignment)  with the `class` attribute.

This example adds padding on the left of the second pill using an SLDS class.

```html
<lightning-pill label="Astro"></lightning-pill>
<lightning-pill label="Codey" class="slds-p-left_x-small"></lightning-pill>
```

To change the background color on a pill, define a custom class using the `class` attribute. This example applies an orange background on a pill.

```html
<lightning-pill label="Astro" class="my-pill"></lightning-pill>
```

Specify the background color on the pill using the `--sds-c-pill-color-background` custom property.

```css
.my-pill {
    --sds-c-pill-color-background: orange;
}
```

For more information, see [Style Components Using Lightning Design System Styling Hooks](docs/component-library/documentation/lwc/lwc.create_components_css_custom_properties) in the Lightning Web Components Developer Guide.


#### Usage Considerations

Icons are not available in Lightning Out, but they are available in Lightning Components for Visualforce and other experiences.

To create more than one pill, use the `lightning-pill-container` component, which gives you access to the pill array via the `itemremove` event.

Specifying a target to change where the link should open is not supported. By default, the link opens on the same tab or window. To create a URL that navigates to another page in Salesforce, use
[`lightning-navigation`](bundle/lightning-navigation/documentation).

This component has usage differences from its Aura counterpart. See [Base Components: Aura Vs Lightning Web Components](docs/component-library/documentation/lwc/lwc.migrate_map_aura_lwc_components) in the Lightning Web Components Developer Guide.

#### Accessibility

When using `lightning-avatar`, use the `alternative-text` attribute to describe the avatar, such as a user's initials or name. This description provides the value for the `alt` attribute in the `img` HTML tag.

When using `lightning-icon`, use the `alternative-text` attribute to describe the icon. For example, specify "Account" instead of "Pill icon". This description is used as assistive text on the pill.

Press the Tab key to focus on a pill. To remove a pill, press the Delete or Backspace key on the pill when it receives focus. Alternatively, press the Enter key when you tab to the remove button. You can define your own behavior to remove the pill from view, such as using the `onremove` handler  shown in __Interacting with Pills__. Press the Enter key to navigate to a link on a pill.

#### Custom Events

**`remove`**

The event fired when a pill is removed.

The `remove` event returns the following parameter.

Parameter|Type|Description
-----|-----|----------
name|string|The name of the pill that's removed.

The event properties are as follows.

Property|Value|Description
-----|-----|----------
bubbles|false|This event does not bubble.
cancelable|true|This event can be canceled. You can call `preventDefault()` on this event to prevent the `click` event from being fired.
composed|false|This event does not propagate outside the template in which it was dispatched.
